mizu API documentation
Description: mizu …

# Package `mizu`

# mizu

Mizu written by rust and used pulldown-cmark.

## Installation

    pip install mizu

Or

    pip install "mizu @ git+https://github.com/tuna2134/mizu"

## Performance

These performance test codes are in tests.

`0.026ms`

## Example

    from mizu import parse

    parse("# Hello tuna2134")

Expand source code

    """
    .. include:: ../README.md
    """
    from .mizu import parse

    __all__ = ("parse",)

## Sub-modules

`mizu.mizu`

  Mizu's core

## Functions

`def parse(...)`

  This function is parse markdown to html.

  ## Args

  `text` :`str`
    Markdown content.

  ## Returns

  `str`
    Html content.